@@ -19,9 +19,9 @@ import yaml
 from . import constants
 from . import generic_io
 from . import reference
-from . import resolver as mresolver
 from . import treeutil
 from . import util
+from .extension import default_extensions
 
 
 YAML_SCHEMA_METASCHEMA_ID = 'http://stsci.edu/schemas/yaml-schema/draft-01'
@@ -36,6 +36,15 @@ else:  # pragma: no cover
 __all__ = ['validate', 'fill_defaults', 'remove_defaults', 'check_schema']
 
 
+def default_ext_resolver(uri):
+    """
+    Resolver that uses tag/url mappings from all installed extensions
+    """
+    tag_mapping = default_extensions.extension_list.tag_mapping
+    url_mapping = default_extensions.extension_list.url_mapping
+    return url_mapping(tag_mapping(uri))
+
+
 PYTHON_TYPE_TO_YAML_TAG = {
     None: 'null',
     str: 'str',
@@ -191,7 +200,7 @@ REMOVE_DEFAULTS['properties'] = validate_remove_default
 
 @lru_cache()
 def _create_validator(validators=YAML_VALIDATORS):
-    meta_schema = load_schema(YAML_SCHEMA_METASCHEMA_ID, mresolver.default_resolver)
+    meta_schema = load_schema(YAML_SCHEMA_METASCHEMA_ID, default_ext_resolver)
     base_cls = mvalidators.create(meta_schema=meta_schema, validators=validators)
 
     class ASDFValidator(base_cls):
@@ -277,7 +286,7 @@ def _load_schema(url):
 
 def _make_schema_loader(resolver):
     def load_schema(url):
-        url = resolver(url)
+        url = resolver(str(url))
         return _load_schema(url)
     return load_schema
 
@@ -359,7 +368,7 @@ def load_schema(url, resolver=None, resolve_references=False,
         control local reference resolution separately.
     """
     if resolver is None:
-        resolver = mresolver.default_resolver
+        resolver = default_ext_resolver
     loader = _make_schema_loader(resolver)
     if url in HARDCODED_SCHEMA:
         schema = HARDCODED_SCHEMA[url]()
@@ -582,9 +591,10 @@ def check_schema(schema):
         'default': validate_default
     })
 
-    meta_schema = load_schema(YAML_SCHEMA_METASCHEMA_ID, mresolver.default_resolver)
+    meta_schema_id = schema.get('$schema', YAML_SCHEMA_METASCHEMA_ID)
+    meta_schema = load_schema(meta_schema_id, default_ext_resolver)
 
-    resolver = _make_resolver(mresolver.default_resolver)
+    resolver = _make_resolver(default_ext_resolver)
 
     cls = mvalidators.create(meta_schema=meta_schema,
                              validators=VALIDATORS)
